==> codegen-2.19.25-sources.jar: software/amazon/awssdk/codegen/model/rules/endpoints/ExpectModel.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package software.amazon.awssdk.codegen.model.rules.endpoints;

import com.fasterxml.jackson.core.TreeNode;
import java.util.List;
import java.util.Map;

public class ExpectModel {
    private String error;
    private Endpoint endpoint;

    public String getError() {
        return error;
    }

    public void setError(String error) {
        this.error = error;
    }

    public Endpoint getEndpoint() {
        return endpoint;
    }

    public void setEndpoint(Endpoint endpoint) {
        this.endpoint = endpoint;
    }

    public static class Endpoint {
        private String url;
        private Map<String, List<String>> headers;
        private Map<String, TreeNode> properties;

        public String getUrl() {
            return url;
        }

        public void setUrl(String url) {
            this.url = url;
        }

        public Map<String, List<String>> getHeaders() {
            return headers;
        }

        public void setHeaders(Map<String, List<String>> headers) {
            this.headers = headers;
        }

        public Map<String, TreeNode> getProperties() {
            return properties;
        }

        public void setProperties(Map<String, TreeNode> properties) {
            this.properties = properties;
        }
    }
}

==> codegen-2.21.38-sources.jar: software/amazon/awssdk/codegen/model/rules/endpoints/ExpectModel.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package software.amazon.awssdk.codegen.model.rules.endpoints;

import com.fasterxml.jackson.core.TreeNode;
import java.util.List;
import java.util.Map;
import software.amazon.awssdk.utils.ToString;

public class ExpectModel {
    private String error;
    private Endpoint endpoint;

    public String getError() {
        return error;
    }

    public void setError(String error) {
        this.error = error;
    }

    public Endpoint getEndpoint() {
        return endpoint;
    }

    public void setEndpoint(Endpoint endpoint) {
        this.endpoint = endpoint;
    }

    @Override
    public String toString() {
        return ToString.builder("ExpectModel")
                       .add("error", error)
                       .add("endpoint", endpoint)
                       .build();
    }

    public static class Endpoint {
        private String url;
        private Map<String, List<String>> headers;
        private Map<String, TreeNode> properties;

        public String getUrl() {
            return url;
        }

        public void setUrl(String url) {
            this.url = url;
        }

        public Map<String, List<String>> getHeaders() {
            return headers;
        }

        public void setHeaders(Map<String, List<String>> headers) {
            this.headers = headers;
        }

        public Map<String, TreeNode> getProperties() {
            return properties;
        }

        public void setProperties(Map<String, TreeNode> properties) {
            this.properties = properties;
        }

        @Override
        public String toString() {
            return ToString.builder("Endpoint")
                           .add("url", url)
                           .add("headers", headers)
                           .add("properties", properties)
                           .build();
        }
    }
}
